@@ -56,22 +56,23 @@ MetaData *get_metadata(gchar * uri);
 MetaData *get_basic_metadata(gchar * uri);
 void strip_unicode(gchar * data, gsize len);
 gint play_iter(GtkTreeIter * playiter, gint restart_second);
-gint detect_playlist(gchar * filename);
+gboolean detect_playlist(gchar * filename);
 gchar *metadata_to_utf8(gchar * string);
-gint parse_playlist(gchar * uri);
-gint parse_asx(gchar * uri);
-gint parse_basic(gchar * filename);
-gint parse_ram(gchar * filename);
-gint parse_cdda(gchar * filename);
-gint parse_dvd(gchar * filename);
-gint parse_vcd(gchar * filename);
+gboolean parse_playlist(gchar * uri);
+gboolean parse_asx(gchar * uri);
+gboolean parse_basic(gchar * filename);
+gboolean parse_ram(gchar * filename);
+gboolean parse_cdda(gchar * filename);
+gboolean parse_dvd(gchar * filename);
+gboolean parse_vcd(gchar * filename);
 gboolean save_playlist_pls(gchar * filename);
 gboolean save_playlist_m3u(gchar * filename);
 gchar *get_path(gchar * filename);
 gboolean streaming_media(gchar * filename);
 gboolean device_name(gchar * filename);
-gboolean add_item_to_playlist(const gchar * uri, gint playlist);
-gboolean first_item_in_playlist(GtkTreeIter * iter);
+gboolean add_item_to_playlist(const gchar * uri, gboolean playlist);
+gboolean is_first_item_in_playlist(GtkTreeIter * iter);
+gboolean first_item_in_playlist(GtkListStore * playliststore, GtkTreeIter * iter);
 gboolean prev_item_in_playlist(GtkTreeIter * iter);
 gboolean next_item_in_playlist(GtkTreeIter * iter);
 void randomize_playlist(GtkListStore * store);
